@@ -30,13 +30,6 @@ _WAVELET_TRANSFORM_DISPLAY = {
     WAVELET_XFORM_5X3_REVERSIBLE: '5-3 reversible'
 }
 
-# Only to be used with QCC and QCD segments.
-_QUANTIZATION_STYLE = {
-    0: '\n    Quantization style:  no quantization, ',
-    1: '\n    Quantization style:  scalar implicit, ',
-    2: '\n    Quantization style:  scalar explicit, ',
-}
-
 _NO_PROFILE = 0
 _PROFILE_0 = 1
 _PROFILE_1 = 2
@@ -96,11 +89,11 @@ class Codestream(object):
     _csiz = -1  # Number of components in the image.
     _parse_tpart_flag = False  # Do we parse the bit stream for SOP / EPH?
 
-    def __init__(self, f, length, header_only=True):
+    def __init__(self, fptr, length, header_only=True):
         """
         Parameters
         ----------
-        f : file
+        fptr : file
             Open file object.
         length : int
             Length of the codestream in bytes.
@@ -169,14 +162,14 @@ class Codestream(object):
             0xffd9: self._parse_eoc_segment
         }
 
-        self.offset = f.tell()
+        self.offset = fptr.tell()
         self.length = length
 
         self.segment = []
 
         # First two bytes are the SOC marker.  We already know that.
-        read_buffer = f.read(2)
-        segment = SOCsegment(offset=f.tell() - 2, length=0)
+        read_buffer = fptr.read(2)
+        segment = SOCsegment(offset=fptr.tell() - 2, length=0)
         self.segment.append(segment)
 
         self._tile_offset = []
@@ -184,17 +177,17 @@ class Codestream(object):
 
         while True:
 
-            read_buffer = f.read(2)
+            read_buffer = fptr.read(2)
             try:
                 self._marker_id, = struct.unpack('>H', read_buffer)
             except struct.error:
-                offset = f.tell() - 2
+                offset = fptr.tell() - 2
                 msg = ('Invalid codestream, expected to find a marker '
                        'at byte position {offset}.')
                 msg = msg.format(offset=offset)
                 raise IOError(msg)
 
-            self._offset = f.tell() - 2
+            self._offset = fptr.tell() - 2
 
             if self._marker_id == 0xff90 and header_only:
                 # Start-of-tile (SOT) means that we are out of the main header
@@ -202,7 +195,7 @@ class Codestream(object):
                 break
 
             try:
-                segment = process_marker_segment[self._marker_id](f)
+                segment = process_marker_segment[self._marker_id](fptr)
             except KeyError:
                 msg = ('Invalid marker ID 0x{marker_id:x} encountered at byte '
                        '{offset:d}.')
@@ -222,38 +215,38 @@ class Codestream(object):
                 if self._parse_tpart_flag and not header_only:
                     # But first parse the tile part bit stream for SOP and
                     # EPH segments.
-                    self._parse_tile_part_bit_stream(f, segment,
+                    self._parse_tile_part_bit_stream(fptr, segment,
                                                      self._tile_length[-1])
 
                 new_offset = self._tile_offset[-1] + self._tile_length[-1]
-                f.seek(new_offset)
+                fptr.seek(new_offset)
 
-    def _parse_unrecognized_segment(self, f):
+    def _parse_unrecognized_segment(self, fptr):
         """Looks like a valid marker, but not sure from reading the specs.
         """
         msg = ("Unrecognized codestream marker 0x{marker_id:x} encountered at "
                "byte offset {offset}.")
-        msg = msg.format(marker_id=self._marker_id, offset=f.tell())
+        msg = msg.format(marker_id=self._marker_id, offset=fptr.tell())
         warnings.warn(msg, UserWarning)
-        cpos = f.tell()
-        read_buffer = f.read(2)
+        cpos = fptr.tell()
+        read_buffer = fptr.read(2)
         next_item, = struct.unpack('>H', read_buffer)
-        f.seek(cpos)
+        fptr.seek(cpos)
         if ((next_item & 0xff00) >> 8) == 255:
                 # No segment associated with this marker, so reset
                 # to two bytes after it.
             segment = Segment(id='0x{0:x}'.format(self._marker_id),
                               offset=self._offset, length=0)
         else:
-            segment = self._parse_reserved_segment(f)
+            segment = self._parse_reserved_segment(fptr)
         return segment
 
-    def _parse_reserved_segment(self, f):
+    def _parse_reserved_segment(self, fptr):
         """Parse valid marker segment, segment description is unknown.
 
         Parameters
         ----------
-        f : file object
+        fptr : file object
             The file to parse.
 
         Returns
@@ -261,12 +254,12 @@ class Codestream(object):
         Segment
             The current segment.
         """
-        offset = f.tell() - 2
+        offset = fptr.tell() - 2
 
-        read_buffer = f.read(2)
+        read_buffer = fptr.read(2)
         length, = struct.unpack('>H', read_buffer)
         if length > 0:
-            data = f.read(length - 2)
+            data = fptr.read(length - 2)
         else:
             data = None
 
@@ -274,9 +267,9 @@ class Codestream(object):
                           offset=offset, length=length, data=data)
         return segment
 
-    def _parse_tile_part_bit_stream(self, f, sod_marker, tile_length):
+    def _parse_tile_part_bit_stream(self, fptr, sod_marker, tile_length):
         """Parse the tile part bit stream for SOP, EPH marker segments."""
-        read_buffer = f.read(tile_length)
+        read_buffer = fptr.read(tile_length)
         # The tile length could possibly be too large and extend past
         # the end of file.  We need to be a bit resilient.
         count = min(tile_length, len(read_buffer))
@@ -311,12 +304,12 @@ class Codestream(object):
             msg += ''.join(strs)
         return msg.rstrip()
 
-    def _parse_cme_segment(self, f):
+    def _parse_cme_segment(self, fptr):
         """Parse the CME marker segment.
 
         Parameters
         ----------
-        f : file
+        fptr : file
             Open file object.
 
         Returns
@@ -324,22 +317,22 @@ class Codestream(object):
         CMESegment
             The current CME segment.
         """
-        offset = f.tell() - 2
+        offset = fptr.tell() - 2
 
-        read_buffer = f.read(4)
+        read_buffer = fptr.read(4)
         data = struct.unpack('>HH', read_buffer)
         length = data[0]
         rcme = data[1]
-        ccme = f.read(length - 4)
+        ccme = fptr.read(length - 4)
 
         return CMEsegment(rcme, ccme, length, offset)
 
-    def _parse_coc_segment(self, f):
+    def _parse_coc_segment(self, fptr):
         """Parse the COC marker segment.
 
         Parameters
         ----------
-        f : file
+        fptr : file
             Open file object.
 
         Returns
@@ -348,35 +341,35 @@ class Codestream(object):
             The current COC segment.
         """
         kwargs = {}
-        offset = f.tell() - 2
+        offset = fptr.tell() - 2
         kwargs['offset'] = offset
 
-        read_buffer = f.read(2)
+        read_buffer = fptr.read(2)
         length, = struct.unpack('>H', read_buffer)
         kwargs['length'] = length
 
         fmt = '>B' if self._csiz <= 255 else '>H'
         nbytes = 1 if self._csiz <= 255 else 2
-        read_buffer = f.read(nbytes)
+        read_buffer = fptr.read(nbytes)
         ccoc, = struct.unpack(fmt, read_buffer)
 
-        read_buffer = f.read(1)
+        read_buffer = fptr.read(1)
         scoc, = struct.unpack('>B', read_buffer)
 
-        numbytes = offset + 2 + length - f.tell()
-        read_buffer = f.read(numbytes)
+        numbytes = offset + 2 + length - fptr.tell()
+        read_buffer = fptr.read(numbytes)
         spcoc = np.frombuffer(read_buffer, dtype=np.uint8)
         spcoc = spcoc
 
         return COCsegment(ccoc, scoc, spcoc, length, offset)
 
     @classmethod
-    def _parse_cod_segment(cls, f):
+    def _parse_cod_segment(cls, fptr):
         """Parse the COD segment.
 
         Parameters
         ----------
-        f : file
+        fptr : file
             Open file object.
 
         Returns
@@ -384,12 +377,12 @@ class Codestream(object):
         CODSegment
             The current COD segment.
         """
-        offset = f.tell() - 2
+        offset = fptr.tell() - 2
 
-        read_buffer = f.read(2)
+        read_buffer = fptr.read(2)
         length, = struct.unpack('>H', read_buffer)
 
-        read_buffer = f.read(length - 2)
+        read_buffer = fptr.read(length - 2)
 
         lst = struct.unpack_from('>BBHBBBBBB', read_buffer, offset=0)
         scod, prog, nlayers, mct, nr, xcb, ycb, cstyle, xform = lst
@@ -412,12 +405,12 @@ class Codestream(object):
 
         return CODsegment(*pargs, length=length, offset=offset)
 
-    def _parse_crg_segment(self, f):
+    def _parse_crg_segment(self, fptr):
         """Parse the CRG marker segment.
 
         Parameters
         ----------
-        f : file
+        fptr : file
             Open file object.
 
         Returns
@@ -425,24 +418,24 @@ class Codestream(object):
         CRGSegment
             The current CRG segment.
         """
-        offset = f.tell() - 2
+        offset = fptr.tell() - 2
 
-        read_buffer = f.read(2)
+        read_buffer = fptr.read(2)
         length, = struct.unpack('>H', read_buffer)
 
-        read_buffer = f.read(4 * self._csiz)
+        read_buffer = fptr.read(4 * self._csiz)
         data = struct.unpack('>' + 'HH' * self._csiz, read_buffer)
         xcrg = data[0::2]
         ycrg = data[1::2]
 
         return CRGsegment(xcrg, ycrg, length, offset)
 
-    def _parse_eoc_segment(self, f):
+    def _parse_eoc_segment(self, fptr):
         """Parse the EOC (end-of-codestream) marker segment.
 
         Parameters
         ----------
-        f : file
+        fptr : file
             Open file object.
 
         Returns
@@ -450,12 +443,12 @@ class Codestream(object):
         EOCSegment
             The current EOC segment.
         """
-        offset = f.tell() - 2
+        offset = fptr.tell() - 2
         length = 0
 
         return EOCsegment(length, offset)
 
-    def _parse_plt_segment(self, f):
+    def _parse_plt_segment(self, fptr):
         """Parse the PLT segment.
 
         The packet headers are not parsed, i.e. they remain uninterpreted raw
@@ -463,7 +456,7 @@ class Codestream(object):
 
         Parameters
         ----------
-        f : file
+        fptr : file
             Open file object.
 
         Returns
@@ -471,13 +464,13 @@ class Codestream(object):
         PLTSegment
             The current PLT segment.
         """
-        offset = f.tell() - 2
+        offset = fptr.tell() - 2
 
-        read_buffer = f.read(3)
+        read_buffer = fptr.read(3)
         length, zplt = struct.unpack('>HB', read_buffer)
 
         numbytes = length - 3
-        read_buffer = f.read(numbytes)
+        read_buffer = fptr.read(numbytes)
         iplt = np.frombuffer(read_buffer, dtype=np.uint8)
 
         packet_len = []
@@ -495,12 +488,12 @@ class Codestream(object):
 
         return PLTsegment(zplt, iplt, length, offset)
 
-    def _parse_pod_segment(self, f):
+    def _parse_pod_segment(self, fptr):
         """Parse the POD segment.
 
         Parameters
         ----------
-        f : file
+        fptr : file
             Open file object.
 
         Returns
@@ -508,26 +501,26 @@ class Codestream(object):
         PODSegment
             The current POD segment.
         """
-        offset = f.tell() - 2
+        offset = fptr.tell() - 2
 
-        read_buffer = f.read(2)
+        read_buffer = fptr.read(2)
         length, = struct.unpack('>H', read_buffer)
 
         n = ((length - 2) / 7) if self._csiz < 257 else ((length - 2) / 9)
         n = int(n)
         nbytes = n * 7 if self._csiz < 257 else n * 9
-        read_buffer = f.read(nbytes)
+        read_buffer = fptr.read(nbytes)
         fmt = '>' + 'BBHBBB' * n if self._csiz < 257 else '>' + 'BHHBHB' * n
         pod_params = struct.unpack(fmt, read_buffer)
 
         return PODsegment(pod_params, length, offset)
 
-    def _parse_ppm_segment(self, f):
+    def _parse_ppm_segment(self, fptr):
         """Parse the PPM segment.
 
         Parameters
         ----------
-        f : file
+        fptr : file
             Open file object.
 
         Returns
@@ -535,17 +528,17 @@ class Codestream(object):
         PPMSegment
             The current PPM segment.
         """
-        offset = f.tell() - 2
+        offset = fptr.tell() - 2
 
-        read_buffer = f.read(3)
+        read_buffer = fptr.read(3)
         length, zppm = struct.unpack('>HB', read_buffer)
 
         numbytes = length - 3
-        read_buffer = f.read(numbytes)
+        read_buffer = fptr.read(numbytes)
 
         return PPMsegment(zppm, read_buffer, length, offset)
 
-    def _parse_ppt_segment(self, f):
+    def _parse_ppt_segment(self, fptr):
         """Parse the PPT segment.
 
         The packet headers are not parsed, i.e. they remain "uninterpreted"
@@ -553,7 +546,7 @@ class Codestream(object):
 
         Parameters
         ----------
-        f : file object
+        fptr : file object
             The file to parse.
 
         Returns
@@ -561,25 +554,25 @@ class Codestream(object):
         PPTSegment
             The current PPT segment.
         """
-        offset = f.tell() - 2
+        offset = fptr.tell() - 2
 
-        read_buffer = f.read(3)
+        read_buffer = fptr.read(3)
         length, zppt = struct.unpack('>HB', read_buffer)
         length = length
         zppt = zppt
 
         numbytes = length - 3
-        ippt = f.read(numbytes)
+        ippt = fptr.read(numbytes)
 
         return PPTsegment(zppt, ippt, length, offset)
 
     @classmethod
-    def _parse_qcc_segment(cls, f):
+    def _parse_qcc_segment(cls, fptr):
         """Parse the QCC segment.
 
         Parameters
         ----------
-        f : file object
+        fptr : file object
             The file to parse.
 
         Returns
@@ -587,12 +580,12 @@ class Codestream(object):
         QCCSegment
             The current QCC segment.
         """
-        offset = f.tell() - 2
+        offset = fptr.tell() - 2
 
-        read_buffer = f.read(2)
+        read_buffer = fptr.read(2)
         length, = struct.unpack('>H', read_buffer)
 
-        read_buffer = f.read(length - 2)
+        read_buffer = fptr.read(length - 2)
         fmt = '>HB' if cls._csiz > 256 else '>BB'
         mantissa_exponent_offset = 3 if cls._csiz > 256 else 2
         cqcc, sqcc = struct.unpack_from(fmt, read_buffer)
@@ -606,12 +599,12 @@ class Codestream(object):
 
         return QCCsegment(cqcc, sqcc, spqcc, length, offset)
 
-    def _parse_qcd_segment(self, f):
+    def _parse_qcd_segment(self, fptr):
         """Parse the QCD segment.
 
         Parameters
         ----------
-        f : file
+        fptr : file
             Open file object.
 
         Returns
@@ -619,21 +612,21 @@ class Codestream(object):
         QCDSegment
             The current QCD segment.
         """
-        offset = f.tell() - 2
+        offset = fptr.tell() - 2
 
-        read_buffer = f.read(3)
+        read_buffer = fptr.read(3)
         length, sqcd = struct.unpack('>HB', read_buffer)
-        spqcd = f.read(length - 3)
+        spqcd = fptr.read(length - 3)
 
         return QCDsegment(sqcd, spqcd, length, offset)
 
     @classmethod
-    def _parse_rgn_segment(cls, f):
+    def _parse_rgn_segment(cls, fptr):
         """Parse the RGN segment.
 
         Parameters
         ----------
-        f : file
+        fptr : file
             Open file object.
 
         Returns
@@ -641,14 +634,14 @@ class Codestream(object):
         RGNSegment
             The current RGN segment.
         """
-        offset = f.tell() - 2
+        offset = fptr.tell() - 2
 
-        read_buffer = f.read(2)
+        read_buffer = fptr.read(2)
         length, = struct.unpack('>H', read_buffer)
 
         nbytes = 3 if cls._csiz < 257 else 4
         fmt = '>BBB' if cls._csiz < 257 else '>HBB'
-        read_buffer = f.read(nbytes)
+        read_buffer = fptr.read(nbytes)
         data = struct.unpack(fmt, read_buffer)
 
         length = length
@@ -659,12 +652,12 @@ class Codestream(object):
         return RGNsegment(crgn, srgn, sprgn, length, offset)
 
     @classmethod
-    def _parse_siz_segment(cls, f):
+    def _parse_siz_segment(cls, fptr):
         """Parse the SIZ segment.
 
         Parameters
         ----------
-        f : file
+        fptr : file
             Open file object.
 
         Returns
@@ -672,12 +665,12 @@ class Codestream(object):
         SIZSegment
             The current SIZ segment.
         """
-        offset = f.tell() - 2
+        offset = fptr.tell() - 2
 
-        read_buffer = f.read(2)
+        read_buffer = fptr.read(2)
         length, = struct.unpack('>H', read_buffer)
 
-        read_buffer = f.read(length - 2)
+        read_buffer = fptr.read(length - 2)
         data = struct.unpack_from('>HIIIIIIIIH', read_buffer)
 
         rsiz = data[0]
@@ -748,12 +741,12 @@ class Codestream(object):
 
         return segment
 
-    def _parse_sod_segment(self, f):
+    def _parse_sod_segment(self, fptr):
         """Parse the SOD (start-of-data) segment.
 
         Parameters
         ----------
-        f : file
+        fptr : file
             Open file object.
 
         Returns
@@ -761,17 +754,17 @@ class Codestream(object):
         SODSegment
             The current SOD segment.
         """
-        offset = f.tell() - 2
+        offset = fptr.tell() - 2
         length = 0
 
         return SODsegment(length, offset)
 
-    def _parse_sot_segment(self, f):
+    def _parse_sot_segment(self, fptr):
         """Parse the SOT segment.
 
         Parameters
         ----------
-        f : file
+        fptr : file
             Open file object.
 
         Returns
@@ -779,9 +772,9 @@ class Codestream(object):
         SOTSegment
             The current SOT segment.
         """
-        offset = f.tell() - 2
+        offset = fptr.tell() - 2
 
-        read_buffer = f.read(10)
+        read_buffer = fptr.read(10)
         data = struct.unpack('>HHIBB', read_buffer)
 
         length = data[0]
@@ -805,13 +798,12 @@ class Codestream(object):
 
         return segment
 
-    @classmethod
-    def _parse_tlm_segment(kls, f):
+    def _parse_tlm_segment(self, fptr):
         """Parse the TLM segment.
 
         Parameters
         ----------
-        f : file
+        fptr : file
             Open file object.
 
         Returns
@@ -819,12 +811,12 @@ class Codestream(object):
         TLMSegment
             The current TLM segment.
         """
-        offset = f.tell() - 2
+        offset = fptr.tell() - 2
 
-        read_buffer = f.read(2)
+        read_buffer = fptr.read(2)
         length, = struct.unpack('>H', read_buffer)
 
-        read_buffer = f.read(length - 2)
+        read_buffer = fptr.read(length - 2)
         ztlm, stlm = struct.unpack_from('>BB', read_buffer)
         ttlm_st = (stlm >> 4) & 0x3
         ptlm_sp = (stlm >> 6) & 0x1
@@ -835,11 +827,21 @@ class Codestream(object):
         else:
             ntiles = nbytes / (ttlm_st + (ptlm_sp + 1) * 2)
 
-        fmt1 = '' if ttlm_st == 0 else 'B' if ttlm_st == 1 else 'H'
-        fmt2 = 'H' if ptlm_sp == 0 else 'I'
-        fmt = '>' + (fmt1 + fmt2) * int(ntiles)
-        data = struct.unpack_from(fmt, read_buffer, offset=2)
+        if ttlm_st == 0:
+            ttlm = None
+            fmt = ''
+        elif ttlm_st == 1:
+            fmt = 'B'
+        elif ttlm_st == 2:
+            fmt = 'H'
 
+        if ptlm_sp == 0:
+            fmt += 'H'
+        else:
+            fmt += 'I'
+
+        data = struct.unpack_from('>' + fmt * int(ntiles), read_buffer,
+                                  offset=2)
         if ttlm_st == 0:
             ttlm = None
             ptlm = data
@@ -849,7 +851,7 @@ class Codestream(object):
 
         return TLMsegment(ztlm, ttlm, ptlm, length, offset)
 
-    def _parse_reserved_marker(self, f):
+    def _parse_reserved_marker(self, fptr):
         """Marker range between 0xff30 and 0xff39.
         """
         the_id = '0x{0:x}'.format(self._marker_id)
@@ -1413,7 +1415,7 @@ class QCCsegment(Segment):
         msg = Segment.__str__(self)
 
         msg += '\n    Associated Component:  {0}'.format(self.cqcc)
-        msg += _QUANTIZATION_STYLE[self.sqcc & 0x01f]
+        msg += _print_quantization_style(self.sqcc)
         msg += '{0} guard bits'.format(self.guard_bits)
 
         step_size = zip(self.mantissa, self.exponent)
@@ -1463,7 +1465,9 @@ class QCDsegment(Segment):
 
     def __str__(self):
         msg = Segment.__str__(self)
-        msg += _QUANTIZATION_STYLE[self.sqcd & 0x01f]
+
+        msg += _print_quantization_style(self.sqcd)
+
         msg += '{0} guard bits'.format(self.guard_bits)
 
         step_size = zip(self.mantissa, self.exponent)
@@ -1897,3 +1901,16 @@ def parse_quantization(read_buffer, sqcd):
             mantissa.append(data[j] & 0x07ff)
 
     return mantissa, exponent
+
+
+def _print_quantization_style(sqcc):
+    """Only to be used with QCC and QCD segments."""
+
+    msg = '\n    Quantization style:  '
+    if sqcc & 0x1f == 0:
+        msg += 'no quantization, '
+    elif sqcc & 0x1f == 1:
+        msg += 'scalar implicit, '
+    elif sqcc & 0x1f == 2:
+        msg += 'scalar explicit, '
+    return msg
